@@ -44,9 +44,8 @@
 	    ;; Meadow
 	    (goto-char (point-min))
 	    (and (re-search-forward "Meadow\\s +" nil t)
-		 (rail-replace-codename-primitive
-		  rail-pj-meadow-format
-		  rail-additional-meadow-codename-alist rail-meadow-codename-alist))
+		 (rail-replace-codename-meadow ?: ?/)
+		 (rail-replace-codename-meadow ?/))
 	    ;; XEmacs
 	    (goto-char (point-min))
 	    (and (re-search-forward "XEmacs\\s +" nil t)
